@@ -1,5 +1,10 @@
+import io
+import re
+import PIL
+
 import requests
 import bs4
+import pytesseract
 
 
 def encode(url):
@@ -27,18 +32,16 @@ class Library:
             if response.text.find("Cloudflare") != -1:
                 raise Exception()
         except Exception:
-            # Get new base_url
-            URL = encode("gssor9..vvv-da`x-bnl.trq.i`ukhaq`qx")
+            # Get new base_url gif
+            URL = encode("gsso9..ykhay-bnl.sdws-fhe")
             response = requests.get(URL, proxies={"http": self.http_proxy})
+            image = PIL.Image.open(io.BytesIO(response.content))
 
-            # Search the page
-            soup = bs4.BeautifulSoup(response.content, features="html.parser")
-            new_url = soup.find("h2", attrs={"class": "bio inline_value"})
-            if new_url is None:
-                raise Exception("Proxy required")
+            # Get base_url by OCR
+            new_url = pytesseract.image_to_string(image)
+            new_url = re.sub("([^a-z0-9]*)", "", new_url)
 
             # New base_url
-            new_url = new_url.getText().split()[1]
             Library.base_url = "http://%s.com/cn/" % new_url
         Library.url_accessible = True
 
@@ -63,12 +66,15 @@ class Library:
         thumblist = soup.select_one(".videothumblist")
         if thumblist is not None:
             # No result
-            video = thumblist.select_one(".video > a")
+            video = thumblist.select(".video > a")
             if video is None:
                 raise Exception("Not recruited")
             
-            # multiple result - choose the first one
-            URL = Library.base_url + video['href']
+            # multiple result - choose the last one
+            if video[0]['title'].endswith("（BOD）"):
+                video = video[1:]
+
+            URL = Library.base_url + video[0]['href']
             response = requests.get(URL, proxies={"http": self.http_proxy}, headers=headers)
             soup = bs4.BeautifulSoup(response.content, features="html.parser")
 
